/v1/projects/{project_id}/virtualbox/vms/{vm_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »

# /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Contents

- /v1/projects/{project_id}/virtualbox/vms/{vm_id}
  - GET /v1/projects/{project_id}/virtualbox/vms/{vm_id}
    - Parameters
    - Response status codes
    - Output
    - Sample session
  - PUT /v1/projects/{project_id}/virtualbox/vms/{vm_id}
    - Parameters
    - Response status codes
    - Input
    - Output
    - Sample session
  - DELETE /v1/projects/{project_id}/virtualbox/vms/{vm_id}
    - Parameters
    - Response status codes

## GET /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Get a VirtualBox VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vm_id | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Sample session

    curl -i -X GET 'http://localhost:8000/projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/f526503a-8d24-4513-a5e3-1ebf4159aa70'

    GET /projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/f526503a-8d24-4513-a5e3-1ebf4159aa70 HTTP/1.1

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 347
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/virtualbox/vms/{vm_id}

    {
        "adapter_type": "Intel PRO/1000 MT Desktop (82540EM)",
        "adapters": 0,
        "console": 2001,
        "enable_remote_console": false,
        "headless": false,
        "name": "VMTEST",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "use_any_adapter": false,
        "vm_id": "f526503a-8d24-4513-a5e3-1ebf4159aa70",
        "vmname": "VMTEST"
    }

## PUT /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Update a VirtualBox VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Instance updated
- 400: Invalid request
- 404: Instance doesn’t exist
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name |  | string | VirtualBox VM instance name
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
adapter_type |  | string | VirtualBox adapter type
adapters |  | integer | number of adapters
console |  | integer | console TCP port
enable_remote_console |  | boolean | enable the remote console
headless |  | boolean | headless mode
name | ✔ | string | VirtualBox VM instance name
project_id | ✔ | string | Project UUID
use_any_adapter |  | boolean | allow GNS3 to use any VirtualBox adapter
vm_id | ✔ | string | VirtualBox VM instance UUID
vmname |  | string | VirtualBox VM name (in VirtualBox itself)

### Sample session

    curl -i -X PUT 'http://localhost:8000/projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/4a6375b9-14b8-406c-ae8e-df6d242088f9' -d '{"console": 2010, "name": "test"}'

    PUT /projects/a1e920ca-338a-4e9f-b363-aa607b09dd80/virtualbox/vms/4a6375b9-14b8-406c-ae8e-df6d242088f9 HTTP/1.1
    {
        "console": 2010,
        "name": "test"
    }

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 345
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/virtualbox/vms/{vm_id}

    {
        "adapter_type": "Intel PRO/1000 MT Desktop (82540EM)",
        "adapters": 0,
        "console": 2010,
        "enable_remote_console": false,
        "headless": false,
        "name": "test",
        "project_id": "a1e920ca-338a-4e9f-b363-aa607b09dd80",
        "use_any_adapter": false,
        "vm_id": "4a6375b9-14b8-406c-ae8e-df6d242088f9",
        "vmname": "VMTEST"
    }

## DELETE /v1/projects/{project_id}/virtualbox/vms/{vm_id}

Delete a VirtualBox VM instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Virtualbox »